==> HTML-Menu-TreeView-0.7.1.tar.gz: HTML-Menu-TreeView-0.7.1/httpdocs/style/Crystal/64/html-menu-treeview/preload.js <==
folderClosed = new Image(64,64);
folderClosed.src='/style/Crystal/64/html-menu-treeview/folderClosed.gif';
plusNode = new Image(64,64);
plusNode.src='/style/Crystal/64/html-menu-treeview/plusNode.gif';
lastPlusNode = new Image(64,64);
lastPlusNode.src='/style/Crystal/64/html-menu-treeview/lastPlusNode.gif';
clasicPlusNode = new Image(64,64);
clasicPlusNode.src='/style/Crystal/64/html-menu-treeview/clasicPlusNode.gif';
clasicLastPlusNode = new Image(64,64);
clasicLastPlusNode.src='/style/Crystal/64/html-menu-treeview/clasicLastPlusNode.gif';
folderManClosed = new Image(64,64);
folderManClosed.src='/style/Crystal/64/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(64,64);
folderGray.src='/style/Crystal/64/html-menu-treeview/folderGray.gif';
folderGreen = new Image(64,64);
folderGreen.src='/style/Crystal/64/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(64,64);
folderViolet.src='/style/Crystal/64/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(64,64);
folderYellowClosed.src='/style/Crystal/64/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(64,64);
folderOrangeClosed.src='/style/Crystal/64/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(64,64);
folderManClosed.src='/style/Crystal/64/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(64,64);
folderHtmlClosed.src='/style/Crystal/64/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(64,64);
folderFavoriteClosed.src='/style/Crystal/64/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(64,64);
folderTextClosed.src='/style/Crystal/64/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(64,64);
folderLockedClosed.src='/style/Crystal/64/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(64,64);
folderCrystalClosed.src='/style/Crystal/64/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(64,64);
folderVideoClosed.src='/style/Crystal/64/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(64,64);
folderPrintClosed.src='/style/Crystal/64/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(64,64);
folderImageClosed.src='/style/Crystal/64/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(64,64);
folderSoundClosed.src='/style/Crystal/64/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(64,64);
folderImportantClosed.src='/style/Crystal/64/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(64,64);
folderTarClosed.src='/style/Crystal/64/html-menu-treeview/folderTarClosed.gif';

==> HTML-Menu-TreeView-0.8.tar.gz: HTML-Menu-TreeView-0.8/httpdocs/style/Crystal/64/html-menu-treeview/preload.js <==
var folderClosed = new Image(64,64);
folderClosed.src='/style/Crystal/64/html-menu-treeview/folderClosed.gif';
var plusNode = new Image(64,64);
plusNode.src='/style/Crystal/64/html-menu-treeview/plusNode.gif';
var lastPlusNode = new Image(64,64);
lastPlusNode.src='/style/Crystal/64/html-menu-treeview/lastPlusNode.gif';
var clasicPlusNode = new Image(64,64);
clasicPlusNode.src='/style/Crystal/64/html-menu-treeview/clasicPlusNode.gif';
var clasicLastPlusNode = new Image(64,64);
clasicLastPlusNode.src='/style/Crystal/64/html-menu-treeview/clasicLastPlusNode.gif';
var folderManClosed = new Image(64,64);
folderManClosed.src='/style/Crystal/64/html-menu-treeview/folderManClosed.gif';
var folderGray = new Image(64,64);
folderGray.src='/style/Crystal/64/html-menu-treeview/folderGray.gif';
var folderGreen = new Image(64,64);
folderGreen.src='/style/Crystal/64/html-menu-treeview/folderGreen.gif';
var folderViolet = new Image(64,64);
folderViolet.src='/style/Crystal/64/html-menu-treeview/folderViolet.gif';
var folderYellowClosed = new Image(64,64);
folderYellowClosed.src='/style/Crystal/64/html-menu-treeview/folderYellowClosed.gif';
var folderOrangeClosed = new Image(64,64);
folderOrangeClosed.src='/style/Crystal/64/html-menu-treeview/folderOrangeClosed.gif';
var folderManClosed = new Image(64,64);
folderManClosed.src='/style/Crystal/64/html-menu-treeview/folderManClosed.gif';
var folderHtmlClosed = new Image(64,64);
folderHtmlClosed.src='/style/Crystal/64/html-menu-treeview/folderHtmlClosed.gif';
var folderFavoriteClosed = new Image(64,64);
folderFavoriteClosed.src='/style/Crystal/64/html-menu-treeview/folderFavoriteClosed.gif';
var folderTextClosed = new Image(64,64);
folderTextClosed.src='/style/Crystal/64/html-menu-treeview/folderTextClosed.gif';
var folderLockedClosed = new Image(64,64);
folderLockedClosed.src='/style/Crystal/64/html-menu-treeview/folderLockedClosed.gif';
var folderCrystalClosed = new Image(64,64);
folderCrystalClosed.src='/style/Crystal/64/html-menu-treeview/folderCrystalClosed.gif';
var folderVideoClosed = new Image(64,64);
folderVideoClosed.src='/style/Crystal/64/html-menu-treeview/folderVideoClosed.gif';
var folderPrintClosed = new Image(64,64);
folderPrintClosed.src='/style/Crystal/64/html-menu-treeview/folderPrintClosed.gif';
var folderImageClosed = new Image(64,64);
folderImageClosed.src='/style/Crystal/64/html-menu-treeview/folderImageClosed.gif';
var folderSoundClosed = new Image(64,64);
folderSoundClosed.src='/style/Crystal/64/html-menu-treeview/folderSoundClosed.gif';
var folderImportantClosed = new Image(64,64);
folderImportantClosed.src='/style/Crystal/64/html-menu-treeview/folderImportantClosed.gif';
var folderTarClosed = new Image(64,64);
folderTarClosed.src='/style/Crystal/64/html-menu-treeview/folderTarClosed.gif';
